@@ -10,6 +10,7 @@ from .apiendpoints import APIEndpoints
 from .apis import Apis
 from .embeds import Embeds
 from .metadata import Metadata
+from .plugins import Plugins
 from .requests import Requests
 from .schemas import Schemas
 
@@ -27,6 +28,7 @@ class SDK:
     apis: Apis
     embeds: Embeds
     metadata: Metadata
+    plugins: Plugins
     requests: Requests
     schemas: Schemas
 
@@ -35,8 +37,8 @@ class SDK:
     _security: shared.Security
     _server_url: str = SERVERS[SERVER_PROD]
     _language: str = "python"
-    _sdk_version: str = "0.14.0"
-    _gen_version: str = "0.22.0"
+    _sdk_version: str = "0.14.1"
+    _gen_version: str = "0.22.1"
 
     def __init__(self) -> None:
         self._client = requests.Session()
